@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "index": 18,
     "lineNumber": 1,
     "column": 19,
