@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "message": "The keyword 'yield' is reserved",
     "column": 7,
     "index": 6,
