@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "message": "Unexpected token foo",
     "column": 3,
     "index": 24,
