@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "message": "Cannot use keyword 'await' outside an async function",
     "column": 7,
     "index": 6,
