@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "index": 41,
     "lineNumber": 2,
     "column": 18,
