@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "message": "Shorthand property assignments are valid only in destructuring patterns",
     "column": 11,
     "index": 10,
