@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "message": "Unexpected token a",
     "column": 7,
     "index": 6,
