@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "message": "Cannot use 'await' as identifier inside an async function",
     "column": 18,
     "index": 41,
