@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "index": 29,
     "lineNumber": 1,
     "column": 30,
