@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "index": 12,
     "lineNumber": 1,
     "column": 13,
