@@ -17,7 +17,7 @@ import * as espree from "../../espree.js";
 
 describe("latestEcmaVersion", () => {
     it("should return the latest supported ecmaVersion", () => {
-        assert.strictEqual(espree.latestEcmaVersion, 13);
+        assert.strictEqual(espree.latestEcmaVersion, 14);
     });
 });
 
@@ -25,7 +25,7 @@ describe("supportedEcmaVersions", () => {
     it("should return an array of all supported versions", () => {
         assert.deepStrictEqual(
             espree.supportedEcmaVersions,
-            [3, 5, 6, 7, 8, 9, 10, 11, 12, 13]
+            [3, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14]
         );
     });
 });
