@@ -21,24 +21,38 @@ import { fileURLToPath } from "url";
 // Helpers
 //------------------------------------------------------------------------------
 
+// eslint-disable-next-line no-underscore-dangle -- Conventional
 const __dirname = path.dirname(fileURLToPath(import.meta.url));
 
+/**
+ * Gets test file names
+ * @param {string} directory The directory
+ * @returns {string[]} The file names
+ */
 function getTestFilenames(directory) {
-    return shelljs.find(directory).filter(function(filename) {
-        return filename.indexOf(".src.js") > -1;
-    }).map(function(filename) {
-        return filename.substring(directory.length - 1, filename.length - 7);  // strip off ".src.js"
-    });
+    return shelljs.find(directory).filter(filename =>
+        filename.indexOf(".src.js") > -1).map(filename =>
+        filename.slice(directory.length - 1, filename.length - 7)); // strip off ".src.js"
 }
 
+/**
+ * Gets library file names
+ * @param {string} directory The directory
+ * @returns {string[]} The file names
+ */
 function getLibraryFilenames(directory) {
-    return shelljs.find(directory).filter(function(filename) {
-        return filename.indexOf(".js") > -1 && filename.indexOf(".result.js") === -1;
-    }).map(function(filename) {
-        return filename.substring(directory.length - 1);  // strip off directory
-    });
+    return shelljs.find(directory).filter(filename =>
+        filename.indexOf(".js") > -1 &&
+            filename.indexOf(".result.js") === -1).map(filename =>
+        filename.slice(directory.length - 1)); // strip off directory
 }
 
+/**
+ * Outputs the result.
+ * @param {any} result The result
+ * @param {string} testResultFilename Test result file name
+ * @returns {void}
+ */
 function outputResult(result, testResultFilename) {
     `export default ${tester.getAstCode(result)};`.to(testResultFilename);
 }
@@ -47,29 +61,30 @@ function outputResult(result, testResultFilename) {
 // Setup
 //------------------------------------------------------------------------------
 
-var FIXTURES_DIR = "./tests/fixtures/ecma-features",
+const FIXTURES_DIR = "./tests/fixtures/ecma-features",
     LIBRARIES_DIR = "./tests/fixtures/libraries";
 
-var testFiles = getTestFilenames(FIXTURES_DIR),
+const testFiles = getTestFilenames(FIXTURES_DIR),
     libraryFiles = getLibraryFilenames(LIBRARIES_DIR);
 
-libraryFiles.forEach(function(filename) {
-    var testResultFilename = path.resolve(__dirname, "..", LIBRARIES_DIR, filename) + ".result.json",
-        code = shelljs.cat(path.resolve(LIBRARIES_DIR, filename)),
-        result = getExpectedResult(code, {
-            loc: true,
-            range: true,
-            tokens: true
-        });
+libraryFiles.forEach(filename => {
+    const testResultFilename = `${path.resolve(__dirname, "..", LIBRARIES_DIR, filename)}.result.json`,
+        code = shelljs.cat(path.resolve(LIBRARIES_DIR, filename));
+    let result = tester.getExpectedResult(code, {
+        loc: true,
+        range: true,
+        tokens: true
+    });
+
     JSON.stringify(result).to(testResultFilename);
     result = null;
 });
 
 // update all tests in ecma-features
-testFiles.forEach(function(filename) {
+testFiles.forEach(filename => {
 
-    var feature = path.dirname(filename),
-        code = shelljs.cat(path.resolve(FIXTURES_DIR, filename) + ".src.js"),
+    const feature = path.dirname(filename),
+        code = shelljs.cat(`${path.resolve(FIXTURES_DIR, filename)}.src.js`),
         config = {
             loc: true,
             range: true,
@@ -79,8 +94,8 @@ testFiles.forEach(function(filename) {
         };
 
     config.ecmaFeatures[feature] = true;
-    var testResultFilename = path.resolve(__dirname, "..", FIXTURES_DIR, filename) + ".result.js";
-    var result = getExpectedResult(code, config);
+    const testResultFilename = `${path.resolve(__dirname, "..", FIXTURES_DIR, filename)}.result.js`;
+    const result = tester.getExpectedResult(code, config);
 
     outputResult(result, testResultFilename);
 });
